@@ -1,4 +1,5 @@
 package Test::Database::Driver::mysql;
+$Test::Database::Driver::mysql::VERSION = '1.111';
 use strict;
 use warnings;
 
@@ -41,7 +42,7 @@ sub databases {
     my ($self)    = @_;
     my $basename  = qr/^@{[$self->_basename()]}/;
     my $databases = eval {
-        DBI->connect_cached( $self->connection_info() )
+        DBI->connect_cached( $self->connection_info(), { PrintError => 0 } )
             ->selectall_arrayref('SHOW DATABASES');
     };
     return grep {/$basename/} map {@$_} @$databases;
@@ -51,6 +52,8 @@ sub databases {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Test::Database::Driver::mysql - A Test::Database driver for mysql
@@ -62,7 +65,7 @@ Test::Database::Driver::mysql - A Test::Database driver for mysql
 
 =head1 DESCRIPTION
 
-This module is the C<Test::Database> driver for C<DBD::mysql>.
+This module is the L<Test::Database> driver for L<DBD::mysql>.
 
 =head1 SEE ALSO
 
@@ -74,8 +77,8 @@ Philippe Bruhat (BooK), C<< <book@cpan.org> >>
 
 =head1 ACKNOWLEDGEMENTS
 
-Many thanks to Kristian Khntopp who helped me while writing a
-previous version of this module (before C<Test::Database> 0.03).
+Many thanks to Kristian Köhntopp who helped me while writing a
+previous version of this module (before L<Test::Database> 0.03).
 
 =head1 COPYRIGHT
 
